@@ -1,4 +1,7 @@
 whereAre <- function(a,b,verbose=TRUE) {
+            checkmate::assert_vector(a)
+            checkmate::assert_vector(b)
+            checkmate::assert_logical(verbose)
             b <- data.frame(1:length(b),b,stringsAsFactors=FALSE)               ### zusaetzliche Syntaxbefehle sind notwendig, damit die Funktion mit missing values umgehen kann.
             if(sum(which(is.na(a)))>0)     {if(verbose) { cat("a contains missing values. \n")}}
             if(sum(which(is.na(b[,2])))>0) {if(verbose) { cat("b contains missing values. \n")}}
