@@ -1,4 +1,6 @@
 wtdVar <- function ( x , weights , na.rm = FALSE) {
+    checkmate::assert_numeric(x)
+    checkmate::assert_numeric(weights, lower = 0)
     if (na.rm) {
       na <- is.na(x) | is.na(weights)
       x <- x[!na]
